@@ -37,6 +37,7 @@ function verifyBody(event, secret) {
   return body;
 }
 exports.handler = async function(event) {
+  var _a;
   if (!process.env.WEBHOOK_SECRET_ARN || !process.env.STEP_FUNCTION_ARN) {
     throw new Error("Missing environment variables");
   }
@@ -94,6 +95,7 @@ exports.handler = async function(event) {
       owner: payload.repository.owner.login,
       repo: payload.repository.name,
       runId: payload.workflow_job.run_id,
+      installationId: (_a = payload.installation) == null ? void 0 : _a.id,
       labels
     }),
     name: executionName
