@@ -149,7 +149,8 @@ app.synth();
 
    1. If it's not called or logs errors, confirm the webhook settings on the GitHub side
    2. If you see too many errors, make sure you're only sending `workflow_job` events
-3. Check execution details of the orchestrator step function by visiting the URL in `troubleshooting.stepFunctionUrl` from `status.json`
+3. When using GitHub app, make sure there are active installation in `github.auth.app.installations`
+4. Check execution details of the orchestrator step function by visiting the URL in `troubleshooting.stepFunctionUrl` from `status.json`
 
    1. Use the details tab to find the specific execution of the provider (Lambda, CodeBuild, Fargate, etc.)
    2. Every step function execution should be successful, even if the runner action inside it failed
@@ -899,7 +900,7 @@ class Secrets(
     def github_private_key(self) -> aws_cdk.aws_secretsmanager.Secret:
         '''(experimental) GitHub app private key. Not needed when using personal authentication tokens.
 
-        This secret is meant to be edited by the user after being created.
+        This secret is meant to be edited by the user after being created. It is separate than the main GitHub secret because inserting private keys into JSON is hard.
 
         :stability: experimental
         '''
